Fix spelling of "occurred".
authorVagrant Cascadian <vagrant@debian.org>
Sun, 1 May 2016 02:18:00 +0000 (19:18 -0700)
committerTom Rini <trini@konsulko.com>
Mon, 2 May 2016 22:37:09 +0000 (18:37 -0400)
Signed-off-by: Vagrant Cascadian <vagrant@debian.org>
Reviewed-by: Simon Glass <sjg@chromium.org>
18 files changed:
board/bf533-ezkit/flash.c
board/mpl/pip405/pip405.c
board/tqc/tqm5200/cmd_stk52xx.c
cmd/fdc.c
common/kgdb.c
common/usb_hub.c
drivers/ddr/marvell/a38x/ddr3_init.h
drivers/ddr/marvell/axp/ddr3_hw_training.h
drivers/i2c/kona_i2c.c
drivers/mtd/nand/omap_gpmc.c
drivers/net/4xx_enet.c
drivers/net/enc28j60.c
drivers/net/ne2000_base.c
drivers/usb/gadget/mpc8xx_udc.c
drivers/usb/musb/musb_hcd.c
include/linux/fb.h
include/test/ut.h
include/usbdevice.h

index 3180a76..a7b3519 100644 (file)
@@ -320,7 +320,7 @@ int poll_toggle_bit(long lOffset)
                }
                timeout--;
        }
-       printf("Time out occured \n");
+       printf("Time out occurred \n");
        if (timeout < 0)
                return FLASH_FAIL;
 }
index 7c7690f..1bd2fbf 100644 (file)
@@ -777,7 +777,7 @@ void print_pip405_info (void)
                        ((sysman & 0x10) == 0x10) ? "" : "not ");
        printf ("INIT asserts %sINT1# (NMI)\n",
                        ((sysman & 0x20) == 0x20) ? "" : "not ");
-       printf ("INIT occured %d\n", (sysman >> 6) & 0x1);
+       printf ("INIT occurred %d\n", (sysman >> 6) & 0x1);
        printf ("SER1 is routed to %s\n",
                        ((flashcom & 0x1) == 0x1) ? "RS485" : "RS232");
        printf ("COM2 is routed to %s\n",
index 9d2d5a8..dc22ee4 100644 (file)
@@ -72,7 +72,7 @@ static int spi_transmit(unsigned char data)
        spi->dr = data;
        /* wait for SPI transmission completed */
        while (!(spi->sr & 0x80)) {
-               if (spi->sr & 0x40) {   /* if write collision occured */
+               if (spi->sr & 0x40) {   /* if write collision occurred */
                        int dummy;
 
                        /* do dummy read to clear status register */
index 058ae89..d2281ab 100644 (file)
--- a/cmd/fdc.c
+++ b/cmd/fdc.c
@@ -189,7 +189,7 @@ int wait_for_fdc_int(void)
        while((read_fdc_reg(FDC_SRA)&0x80)==0) {
                timeout--;
                udelay(10);
-               if(timeout==0) /* timeout occured */
+               if(timeout==0) /* timeout occurred */
                        return false;
        }
        return true;
@@ -205,7 +205,7 @@ int read_fdc_byte(void)
                /* direction out and ready */
                udelay(10);
                timeout--;
-               if(timeout==0) /* timeout occured */
+               if(timeout==0) /* timeout occurred */
                        return -1;
        }
        return read_fdc_reg(FDC_FIFO);
@@ -235,7 +235,7 @@ int write_fdc_byte(unsigned char val)
                timeout--;
                udelay(10);
                fdc_need_more_output();
-               if(timeout==0) /* timeout occured */
+               if(timeout==0) /* timeout occurred */
                        return false;
        }
        write_fdc_reg(FDC_FIFO,val);
@@ -395,7 +395,7 @@ int fdc_terminate(FDC_COMMAND_STRUCT *pCMD)
        int i;
        for(i=0;i<100;i++)
                udelay(500); /* wait 500usec for fifo overrun */
-       while((read_fdc_reg(FDC_SRA)&0x80)==0x00); /* wait as long as no int has occured */
+       while((read_fdc_reg(FDC_SRA)&0x80)==0x00); /* wait as long as no int has occurred */
        for(i=0;i<7;i++) {
                pCMD->result[i]=(unsigned char)read_fdc_byte();
        }
index d357463..daf53be 100644 (file)
@@ -326,7 +326,7 @@ handle_exception (struct pt_regs *regs)
                return (0);
        }
 
/* probably should check which exception occured as well */
        if (longjmp_on_fault) {
                longjmp_on_fault = 0;
                kgdb_longjmp(error_jmp_buf, KGDBERR_MEMFAULT);
index e6a2cdb..4f59802 100644 (file)
@@ -475,7 +475,7 @@ static int usb_scan_port(struct usb_device_scan *usb_scan)
                        return 0;
 
                /* Otherwise the device will get removed */
-               printf("Port %d over-current occured %d times\n", i + 1,
+               printf("Port %d over-current occurred %d times\n", i + 1,
                       hub->overcurrent_count[i]);
        }
 
index cb3fb24..8cb0886 100644 (file)
 #define MV_NO_RESOURCE (0x13)  /* Resource not available (memory ...)   */
 #define MV_FULL                (0x14)  /* Item is full (Queue or table etc...)  */
 #define MV_EMPTY       (0x15)  /* Item is empty (Queue or table etc...) */
-#define MV_INIT_ERROR  (0x16)  /* Error occured while INIT process      */
+#define MV_INIT_ERROR  (0x16)  /* Error occurred while INIT process      */
 #define MV_HW_ERROR    (0x17)  /* Hardware error                        */
 #define MV_TX_ERROR    (0x18)  /* Transmit operation not succeeded      */
 #define MV_RX_ERROR    (0x19)  /* Recieve operation not succeeded       */
index cffa7c4..343a6b6 100644 (file)
@@ -41,7 +41,7 @@
 #define MV_NO_RESOURCE (0x13)  /* Resource not available (memory ...)   */
 #define MV_FULL                (0x14)  /* Item is full (Queue or table etc...)  */
 #define MV_EMPTY       (0x15)  /* Item is empty (Queue or table etc...) */
-#define MV_INIT_ERROR  (0x16)  /* Error occured while INIT process      */
+#define MV_INIT_ERROR  (0x16)  /* Error occurred while INIT process      */
 #define MV_HW_ERROR    (0x17)  /* Hardware error                        */
 #define MV_TX_ERROR    (0x18)  /* Transmit operation not succeeded      */
 #define MV_RX_ERROR    (0x19)  /* Recieve operation not succeeded       */
index 9af496b..11f29d9 100644 (file)
@@ -381,7 +381,7 @@ static int bcm_kona_i2c_write_fifo_single(struct bcm_kona_i2c_dev *dev,
                return -EREMOTEIO;
        }
 
/* Check if a timeout occured */
        if (!time_left) {
                printf("completion timed out\n");
                return -EREMOTEIO;
index 4814fa2..6a45d28 100644 (file)
@@ -106,7 +106,7 @@ static uint32_t gen_true_ecc(uint8_t *ecc_buf)
 
 /*
  * omap_correct_data - Compares the ecc read from nand spare area with ECC
* registers values and corrects one bit error if it has occured
  * Further details can be had from OMAP TRM and the following selected links:
  * http://en.wikipedia.org/wiki/Hamming_code
  * http://www.cs.utexas.edu/users/plaxton/c/337/05f/slides/ErrorCorrection-4.pdf
@@ -479,7 +479,7 @@ static void omap_reverse_list(u8 *list, unsigned int length)
 
 /*
  * omap_correct_data_bch - Compares the ecc read from nand spare area
* with ECC registers values and corrects one bit error if it has occured
  *
  * @mtd:       MTD device structure
  * @dat:       page data
index 3c30f42..bc52ed3 100644 (file)
@@ -1726,7 +1726,7 @@ static void mal_err (struct eth_device *dev, unsigned long isr,
        mtdcr (MAL0_RXDEIR, 0x80000000);
 
 #ifdef INFO_4XX_ENET
-       printf("\nMAL error occured.... ISR = %lx UIC = = %lx   MAL_DEF = %lx  MAL_ERR= %lx\n",
+       printf("\nMAL error occurred.... ISR = %lx UIC = = %lx  MAL_DEF = %lx  MAL_ERR= %lx\n",
               isr, uic, maldef, mal_errr);
 #endif
 
@@ -1740,7 +1740,7 @@ static void emac_err (struct eth_device *dev, unsigned long isr)
 {
        EMAC_4XX_HW_PST hw_p = dev->priv;
 
-       printf ("EMAC%d error occured.... ISR = %lx\n", hw_p->devnum, isr);
+       printf ("EMAC%d error occurred.... ISR = %lx\n", hw_p->devnum, isr);
        out_be32((void *)EMAC0_ISR + hw_p->hw_addr, isr);
 }
 
index 59ea11c..611eabb 100644 (file)
@@ -381,7 +381,7 @@ static int enc_phy_link_wait(enc_dev_t *enc)
                udelay(1000);
        }
 
-       /* timeout occured */
+       /* timeout occurred */
        printf("%s: link down\n", enc->dev->name);
        return 1;
 }
index 71d133c..67bf140 100644 (file)
@@ -582,7 +582,7 @@ dp83902a_Overflow(void)
        /*
         * Read in as many packets as we can and acknowledge any and receive
         * interrupts. Since the buffer has overflowed, a receive event of
* some kind will have occured.
         */
        dp83902a_RxEvent();
        DP_OUT(base, DP_ISR, DP_ISR_RxP|DP_ISR_RxE);
@@ -592,7 +592,7 @@ dp83902a_Overflow(void)
        DP_OUT(base, DP_TCR, DP_TCR_NORMAL);
 
        /*
* If a transmit command was issued, but no transmit event has occured,
         * restart it here.
         */
        DP_IN(base, DP_ISR, isr);
index b3e178a..ad5ea7a 100644 (file)
@@ -170,7 +170,7 @@ int udc_init (void)
 
 /* udc_irq
  *
* Poll for whatever events may have occured
  */
 void udc_irq (void)
 {
index 9a3b61a..4947936 100644 (file)
@@ -73,9 +73,9 @@ static void write_toggle(struct usb_device *dev, u8 ep, u8 dir_out)
 }
 
 /*
* This function checks if RxStall has occured on the endpoint. If a RxStall
* has occured, the RxStall is cleared and 1 is returned. If RxStall has
* not occured, 0 is returned.
  */
 static u8 check_stall(u8 ep, u8 dir_out)
 {
index 652cf3b..fcf331b 100644 (file)
@@ -388,14 +388,14 @@ struct fb_cursor_user {
 #define FB_EVENT_GET_CONSOLE_MAP       0x07
 /*     CONSOLE-SPECIFIC: set console to framebuffer mapping */
 #define FB_EVENT_SET_CONSOLE_MAP       0x08
/*     A hardware display blank change occured */
 #define FB_EVENT_BLANK                 0x09
 /*     Private modelist is to be replaced */
 #define FB_EVENT_NEW_MODELIST          0x0A
 /*     The resolution of the passed in fb_info about to change and
        all vc's should be changed         */
 #define FB_EVENT_MODE_CHANGE_ALL       0x0B
/*     A software display blank change occured */
 #define FB_EVENT_CONBLANK              0x0C
 /*     Get drawing requirements        */
 #define FB_EVENT_GET_REQ               0x0D
index da7c1a9..85434d7 100644 (file)
@@ -17,9 +17,9 @@ struct unit_test_state;
  * ut_fail() - Record failure of a unit test
  *
  * @uts: Test state
* @fname: Filename where the error occured
* @line: Line number where the error occured
* @func: Function name where the error occured
  * @cond: The condition that failed
  */
 void ut_fail(struct unit_test_state *uts, const char *fname, int line,
@@ -29,9 +29,9 @@ void ut_fail(struct unit_test_state *uts, const char *fname, int line,
  * ut_failf() - Record failure of a unit test
  *
  * @uts: Test state
* @fname: Filename where the error occured
* @line: Line number where the error occured
* @func: Function name where the error occured
  * @cond: The condition that failed
  * @fmt: printf() format string for the error, followed by args
  */
index da5af6e..f27e17f 100644 (file)
@@ -438,7 +438,7 @@ typedef enum usb_device_event {
        DEVICE_HUB_RESET,       /* bi  - bus has been unplugged */
        DEVICE_DESTROY,         /* bi  - device instance should be destroyed */
 
-       DEVICE_HOTPLUG,         /* bi  - a hotplug event has occured */
+       DEVICE_HOTPLUG,         /* bi  - a hotplug event has occurred */
 
        DEVICE_FUNCTION_PRIVATE,        /* function - private */
@@ -326,7 +326,7 @@ handle_exception (struct pt_regs *regs)
        }
 
-       /* probably should check which exception occured as well */
+       /* probably should check which exception occurred as well */
        if (longjmp_on_fault) {
                longjmp_on_fault = 0;
@@ -381,7 +381,7 @@ static int bcm_kona_i2c_write_fifo_single(struct bcm_kona_i2c_dev *dev,
        }
 
-       /* Check if a timeout occured */
+       /* Check if a timeout occurred */
        if (!time_left) {
                printf("completion timed out\n");
@@ -106,7 +106,7 @@ static uint32_t gen_true_ecc(uint8_t *ecc_buf)
 /*
  * omap_correct_data - Compares the ecc read from nand spare area with ECC
- * registers values and corrects one bit error if it has occured
+ * registers values and corrects one bit error if it has occurred
  * Further details can be had from OMAP TRM and the following selected links:
  * http://en.wikipedia.org/wiki/Hamming_code
@@ -479,7 +479,7 @@ static void omap_reverse_list(u8 *list, unsigned int length)
 /*
  * omap_correct_data_bch - Compares the ecc read from nand spare area
- * with ECC registers values and corrects one bit error if it has occured
+ * with ECC registers values and corrects one bit error if it has occurred
  *
  * @mtd:       MTD device structure
@@ -582,7 +582,7 @@ dp83902a_Overflow(void)
         * Read in as many packets as we can and acknowledge any and receive
         * interrupts. Since the buffer has overflowed, a receive event of
-        * some kind will have occured.
+        * some kind will have occurred.
         */
        dp83902a_RxEvent();
@@ -592,7 +592,7 @@ dp83902a_Overflow(void)
 
        /*
-        * If a transmit command was issued, but no transmit event has occured,
+        * If a transmit command was issued, but no transmit event has occurred,
         * restart it here.
         */
@@ -170,7 +170,7 @@ int udc_init (void)
 /* udc_irq
  *
- * Poll for whatever events may have occured
+ * Poll for whatever events may have occurred
  */
 void udc_irq (void)
@@ -73,9 +73,9 @@ static void write_toggle(struct usb_device *dev, u8 ep, u8 dir_out)
 
 /*
- * This function checks if RxStall has occured on the endpoint. If a RxStall
- * has occured, the RxStall is cleared and 1 is returned. If RxStall has
- * not occured, 0 is returned.
+ * This function checks if RxStall has occurred on the endpoint. If a RxStall
+ * has occurred, the RxStall is cleared and 1 is returned. If RxStall has
+ * not occurred, 0 is returned.
  */
 static u8 check_stall(u8 ep, u8 dir_out)
@@ -388,14 +388,14 @@ struct fb_cursor_user {
 /*     CONSOLE-SPECIFIC: set console to framebuffer mapping */
 #define FB_EVENT_SET_CONSOLE_MAP       0x08
-/*     A hardware display blank change occured */
+/*     A hardware display blank change occurred */
 #define FB_EVENT_BLANK                 0x09
 /*     Private modelist is to be replaced */
@@ -388,14 +388,14 @@ struct fb_cursor_user {
        all vc's should be changed         */
 #define FB_EVENT_MODE_CHANGE_ALL       0x0B
-/*     A software display blank change occured */
+/*     A software display blank change occurred */
 #define FB_EVENT_CONBLANK              0x0C
 /*     Get drawing requirements        */
@@ -17,9 +17,9 @@ struct unit_test_state;
  *
  * @uts: Test state
- * @fname: Filename where the error occured
- * @line: Line number where the error occured
- * @func: Function name where the error occured
+ * @fname: Filename where the error occurred
+ * @line: Line number where the error occurred
+ * @func: Function name where the error occurred
  * @cond: The condition that failed
  */
@@ -29,9 +29,9 @@ void ut_fail(struct unit_test_state *uts, const char *fname, int line,
  *
  * @uts: Test state
- * @fname: Filename where the error occured
- * @line: Line number where the error occured
- * @func: Function name where the error occured
+ * @fname: Filename where the error occurred
+ * @line: Line number where the error occurred
+ * @func: Function name where the error occurred
  * @cond: The condition that failed
  * @fmt: printf() format string for the error, followed by args